@@ -1,5 +1,6 @@
 """Constants for netbox_onboarding plugin."""
-NETMIKO_TO_NAPALM = {
+
+NETMIKO_TO_NAPALM_STATIC = {
     "cisco_ios": "ios",
     "cisco_nxos": "nxos_ssh",
     "arista_eos": "eos",
