@@ -16,18 +16,30 @@ import django_filters
 from django.db.models import Q
 
 from dcim.models import Site, DeviceRole, Platform
-from utilities.filters import NameSlugSearchFilterSet
 
+from .release import NETBOX_RELEASE_CURRENT, NETBOX_RELEASE_211
 from .models import OnboardingTask
 
 
-class OnboardingTaskFilter(NameSlugSearchFilterSet):
+if NETBOX_RELEASE_CURRENT < NETBOX_RELEASE_211:
+    from utilities.filters import NameSlugSearchFilterSet  # pylint: disable=no-name-in-module, import-error
+
+    class FitersetMixin(NameSlugSearchFilterSet):
+        """FilterSet Mixin."""
+
+
+else:
+    from netbox.filtersets import BaseFilterSet  # pylint: disable=no-name-in-module, import-error
+
+    class FitersetMixin(BaseFilterSet):
+        """FilterSet Mixin."""
+
+
+class OnboardingTaskFilter(FitersetMixin):
     """Filter capabilities for OnboardingTask instances."""
 
     q = django_filters.CharFilter(method="search", label="Search",)
 
-    site_id = django_filters.ModelMultipleChoiceFilter(queryset=Site.objects.all(), label="Site (ID)",)
-
     site = django_filters.ModelMultipleChoiceFilter(
         field_name="site__slug", queryset=Site.objects.all(), to_field_name="slug", label="Site (slug)",
     )
@@ -46,7 +58,7 @@ class OnboardingTaskFilter(NameSlugSearchFilterSet):
         model = OnboardingTask
         fields = ["id", "site", "site_id", "platform", "role", "status", "failed_reason"]
 
-    def search(self, queryset, name, value):
+    def search(self, queryset, name, value):  # pylint: disable=unused-argument, no-self-use
         """Perform the filtered search."""
         if not value.strip():
             return queryset
@@ -55,7 +67,7 @@ class OnboardingTaskFilter(NameSlugSearchFilterSet):
             | Q(ip_address__icontains=value)
             | Q(site__name__icontains=value)
             | Q(platform__name__icontains=value)
-            | Q(device__icontains=value)
+            | Q(created_device__name__icontains=value)
             | Q(status__icontains=value)
             | Q(failed_reason__icontains=value)
             | Q(message__icontains=value)
