@@ -12,8 +12,11 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 from django.urls import path
+from extras.views import ObjectChangeLogView
 
+from .models import OnboardingTask
 from .views import (
+    OnboardingTaskView,
     OnboardingTaskListView,
     OnboardingTaskCreateView,
     OnboardingTaskBulkDeleteView,
@@ -21,8 +24,15 @@ from .views import (
 )
 
 urlpatterns = [
-    path("", OnboardingTaskListView.as_view(), name="onboarding_task_list"),
-    path("add/", OnboardingTaskCreateView.as_view(), name="onboarding_task_add"),
-    path("delete/", OnboardingTaskBulkDeleteView.as_view(), name="onboarding_task_bulk_delete"),
-    path("import/", OnboardingTaskFeedBulkImportView.as_view(), name="onboarding_task_import"),
+    path("", OnboardingTaskListView.as_view(), name="onboardingtask_list"),
+    path("<int:pk>/", OnboardingTaskView.as_view(), name="onboardingtask"),
+    path("add/", OnboardingTaskCreateView.as_view(), name="onboardingtask_add"),
+    path("delete/", OnboardingTaskBulkDeleteView.as_view(), name="onboardingtask_bulk_delete"),
+    path("import/", OnboardingTaskFeedBulkImportView.as_view(), name="onboardingtask_import"),
+    path(
+        "<int:pk>/changelog/",
+        ObjectChangeLogView.as_view(),
+        name="onboardingtask_changelog",
+        kwargs={"model": OnboardingTask},
+    ),
 ]
